RouterBuilder

Struct RouterBuilder 

pub struct RouterBuilder { /* private fields */ }
Builds application with routing.

Implementations

Source

impl RouterBuilder

pub fn add_page<C>(self, path: &'static str) -> RouterBuilder
where C: Component + Default + 'static,

Adds provided page to application under provided path in variable path. Page is represented by custom component - struct implementing trait Component and Default.

pub fn add_not_found_page<C>(self) -> RouterBuilder
where C: Component + Default + 'static,

Adds provided not found page to application. All routes which cannot be resolved will be redirected to this page. Adding more than one not found page results in undefined behavior.

Source

impl RouterBuilder

pub fn build(self) -> Router

Builds router. If not found page was not specified, default one is provided.