pub struct VElement { /* private fields */ }Expand description
Represents Element in DOM.
Implementations
Sourceimpl VElement
impl VElement
Sourcepub fn new(
tag_name: String,
attr: HashMap<String, String>,
event_handlers: Vec<EventHandler>,
key: Option<String>,
children: Vec<VNode>,
) -> VElement
pub fn new( tag_name: String, attr: HashMap<String, String>, event_handlers: Vec<EventHandler>, key: Option<String>, children: Vec<VNode>, ) -> VElement
Creates VElement out of provided arguments. Optional key is a way of easy comparison, if key is some and keys match, old element is used.
Example
let element = VElement::new(
String::from("div") // tag_name,
[(String::from("id"),String::from("example"))].into(), // attr,
vec![], // event_handlers,
None, // key,
vec![VNode::Text(VText::new("child"))] // children
);Trait Implementations