VList

Struct VList 

pub struct VList { /* private fields */ }
A list of nodes of virtual DOM tree. It undergoes virtual DOM manipulations and patching algorithm optimizations.

Implementations

Source

impl VList

pub fn new(nodes: Vec<VNode>, key: Option<String>) -> VList

Creates a VList out of vector of VNodes. Optional key works as an easy comparison option, if keys match, old VList is used.

pub fn new_empty(key: Option<String>) -> VList

Creates an empty VList. Optional key works as an easy comparison option, if keys match, old VList is used.