pub struct RouterBuilder { /* private fields */ }Expand description
Builds application with routing.
Implementations
Sourceimpl RouterBuilder
impl RouterBuilder
Sourcepub fn add_page<C>(self, path: &'static str) -> RouterBuilder
pub fn add_page<C>(self, path: &'static str) -> RouterBuilder
Sourcepub fn add_not_found_page<C>(self) -> RouterBuilder
pub fn add_not_found_page<C>(self) -> RouterBuilder
Adds provided not found page to application. All routes which cannot be resolved will be redirected to this page. Adding more than one not found page results in undefined behavior.